camel property
The normalized camelCase name.
This value is used for generated variables, route names, and endpoint
constants, such as userProfile.
Implementation
final String camel;
The normalized camelCase name.
This value is used for generated variables, route names, and endpoint
constants, such as userProfile.
final String camel;