pascal property
The normalized PascalCase name.
This value is used for generated Dart types, such as UserProfileBloc.
Implementation
final String pascal;
The normalized PascalCase name.
This value is used for generated Dart types, such as UserProfileBloc.
final String pascal;