snake property
The normalized snake_case name.
This value is used for generated folders and files, such as
features/user_profile and user_profile_page.dart.
Implementation
final String snake;
The normalized snake_case name.
This value is used for generated folders and files, such as
features/user_profile and user_profile_page.dart.
final String snake;